@@ -1,3 +1,11 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+"""
+Created on Tue Jun  2 21:44:58 2020
+
+@author: ryangosselin
+"""
+
 # LDA: linear discriminate analysis
 
 import numpy as np
@@ -66,14 +74,15 @@ def LDA(nbPC, *args):
     Sb = Sb / np.sum(N)
 
     # Compute LDA projections
-    Swinv = np.linalg.inv(Sw)
+    Swinv = np.linalg.pinv(Sw) #Use pseudo-inverse to avoir rank issues
     SwinvSb = Swinv@Sb
     
     U,D,V = np.linalg.svd(SwinvSb)
-    P = U
+    P = U[:,:nbPC]
+    
     # Correct for rotational ambiguity
     for i in range(P.shape[1]):
-        if P[i,:][np.newaxis]@np.ones((P.shape[0],1)) < 0:
+        if P[:,i][np.newaxis]@np.ones((P.shape[0],1)) < 0:
             P[:,i] = -P[:,i]
     
     # Create overall X matrix containing n blocks    
@@ -100,4 +109,12 @@ def LDA(nbPC, *args):
         SSX[i] = ssX
     # --------------------------
 
+    
+    # Sort by SSX   
+    sort = np.argsort(SSX.T) 
+    sort = np.fliplr(sort) # Decreasing order
+    SSX = SSX[sort]
+    T = np.squeeze(T[:,sort])
+    P = np.squeeze(P[:,sort])
+
     return T,P,SSX
\ No newline at end of file
