@@ -1,8 +1,31 @@
-# PCA with NIPALS
+# PCA: principal component analysis
 
 import numpy as np
 
 def PCA(X, nbPC):
+    ''' 
+    
+    PCA: principal component analysis
+    [T,P,SSX] = PCA(X, nbPC)
+    
+    INPUT
+    npPC [1 x 1] <numpy.ndarray>
+        number of components in the PCA decomposition
+    X [n x k] <numpy.ndarray>
+        spectra
+        n samples
+        k variables
+    
+    OUTPUT
+    T [n x nbPC] 
+        scores
+    P [nbPC x k] 
+        loadings
+    SSX [1 x nbPC] 
+        Sum of squared variance explained by each component
+        
+    '''
+    
     s0, s1 = X.shape
     T = np.zeros((s0, nbPC))
     P = np.zeros((s1, nbPC))
@@ -17,7 +40,12 @@ def PCA(X, nbPC):
         while error > 1E-10:
             p = (X.T@t)/(t.T@t)
             p = p/np.linalg.norm(p,2)
-            # np.linalg.norm(p,2) = np.max(np.sqrt(p.T @ p))
+
+            # Fix rotational ambiguity
+            onez = np.ones([len(p),1]) # Use as a reference
+            if p.T@onez < 0:
+                p = -p
+
             t = (X@p)/(p.T@p)
             # Check t convergence --------------------
             error = sum(np.power((t-t_temp),2),0) # Squared error
@@ -33,6 +61,6 @@ def PCA(X, nbPC):
         ssX = np.sum(np.sum(Xhat * Xhat))
         ssX = ssX / ssX0
         SSX[i] = ssX
-        # --------------------------
+        # --------------------------    
         
     return T, P, SSX
